@@ -6,7 +6,7 @@
 
 #include <stdio.h>
 
-#include <strstream.h>		// Evil, old API
+#include <sstream>
 
 #include "gql++/object.h"
 #include "gql++/driver.h"
@@ -22,7 +22,7 @@ Connection::~Connection()
 
 SQLObject *Connection::create_object()
 {
-  return new SQLObject();
+  return new BasicSQLObject();
 }
 
 SQLObject *Connection::create_blob()
