@@ -4,27 +4,23 @@
 
 #include <stdexcept>
 
-#include "gql++config.h"
-
 namespace GQL
 {
 
-using namespace std;
-
-class SQLException : public runtime_error
+class SQLException : public std::runtime_error
 {
   public:
-    SQLException(const string& str = string(),
-                 const string& state = string(),
+    SQLException(const std::string& str = std::string(),
+                 const std::string& state = std::string(),
                  int err = 0)
         : runtime_error(str), state_(state), vendor_code_(err) { }
     virtual ~SQLException() throw() { }
 
     const char *get_message() const { return(what()); }
     int get_error_code() const { return(vendor_code_); }
-    const string& get_sql_state() const { return(state_); }
+    const std::string& get_sql_state() const { return(state_); }
   private:
-    string state_;
+    std::string state_;
     int vendor_code_;
 };
 
