@@ -1,9 +1,9 @@
 /* This is for emacs: -*-Mode: C++;-*- */
-#if !defined(__INC_STATEMENT_H)
-#define __INC_STATEMENT_H
+#if !defined(__INC_GQL_STATEMENT_H)
+#define __INC_GQL_STATEMENT_H
 
-#include "gql++/warnable.h"
-#include "gql++/connection.h"
+#include <gql++/warnable.h>
+#include <gql++/connection.h>
 
 namespace GQL
 {
@@ -16,13 +16,15 @@ class Statement : public Warnable
     Statement(Connection *conn) : conn_(conn) { }
     virtual ~Statement() { }
 
-    virtual bool execute(const string& sql) = 0;
+    virtual bool execute(const std::string& sql) = 0;
 
-    virtual ResultSet *execute_query(const string& sql) = 0;
-    virtual int execute_update(const string& sql) = 0;
+    virtual ResultSet *execute_query(const std::string& sql) = 0;
+    virtual int execute_update(const std::string& sql) = 0;
 
-    Connection *get_connection() { return(conn_); }
-    const Connection *get_connection() const { return(conn_); }
+    virtual int get_update_count() const = 0;
+    
+    Connection *get_connection() { return conn_; }
+    const Connection *get_connection() const { return conn_; }
     
     virtual ResultSet *get_result_set() = 0;
     virtual bool get_more_results() = 0;
