@@ -4,9 +4,9 @@
 
 #include <queue>
 
-#include <sigc++/signal_system.h>
+#include <sigc++/sigc++.h>
 
-#include "gql++/warning.h"
+#include <gql++/warning.h>
 
 namespace GQL
 {
@@ -33,7 +33,7 @@ class Warnable : public SigC::Object
       warnings_.push(warning);
     }
   private:
-    queue<SQLWarning *> warnings_;
+    std::queue<SQLWarning *> warnings_;
 };
 
 }
