@@ -2,6 +2,8 @@
 #if !defined(__INC_WARNING_H)
 #define __INC_WARNING_H
 
+#include <string>
+
 #include "gql++/exception.h"
 
 namespace GQL
@@ -10,9 +12,9 @@ namespace GQL
 class SQLWarning : public SQLException
 {
   public:
-    SQLWarning(const string& str = string(),
-                 const string& state = string(),
-                 int err = 0)
+    SQLWarning(const std::string& str = std::string(),
+               const std::string& state = std::string(),
+               int err = 0)
         : SQLException(str, state, err) { }
 };
 
